@@ -17,6 +17,8 @@ except ImportError:
     SELF_ADDRESS = 'proxy@kavahq.com'
     PROCESS_OUTGOING_EMAILS = False
 
+PROJECT_NAME = None
+
 if __name__ == "__main__":
     try:
         from mail_route_settings import PROJECT_BASE_DIR, DJANGO_SETTINGS_MODULE, LOG_PATH, PROJECT_NAME
@@ -49,8 +51,9 @@ from email_filter.signals import mail_for_unknown_user
 
 # check django settings:
 from django.conf import settings
-from django.utils.importlib import import_module
-import_module(PROJECT_NAME)
+if PROJECT_NAME:
+    from django.utils.importlib import import_module
+    import_module(PROJECT_NAME)
 
 # import all apps to get proper signal processing:
 for app in settings.INSTALLED_APPS:
